[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

Bug#770666: marked as done (partman-base: partman overwrites parts of u-boot (imx6/am335x))



Your message dated Sun, 23 Nov 2014 11:49:25 +0000
with message-id <E1XsVfR-0006I1-DC@franck.debian.org>
and subject line Bug#770666: fixed in partman-base 180
has caused the Debian Bug report #770666,
regarding partman-base: partman overwrites parts of u-boot (imx6/am335x)
to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact owner@bugs.debian.org
immediately.)


-- 
770666: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=770666
Debian Bug Tracking System
Contact owner@bugs.debian.org with problems
--- Begin Message ---
Package: partman-base
Version: 179
Severity: important
Tags: patch

Several armhf platforms have u-boot installed directly to the device
in an area which gets wiped out by partman. This results in
debian-installer producing a "successful" install, but zeros out the
location of the bootloader in the process... so fails to boot.

This was fixed for sunxi/allwinner platforms (see:
https://bugs.debian.org/751704), but other platforms such as imx6
(Wandboard, CuBox-i) and am335x (BeagleBone Black) are still affected
by the issue.

The following proof-of-concept patch may be a little too broad,
affecting all Freescale or AM33XX systems, although it is limited to
installs to /dev/mmcblk0. BeagleBone Black may also need this code
when installing to /dev/mmcblk1...

Essentially it renames the is_sunxi_system to
is_system_with_firmware_on_disk, and adds cases for the additional
platforms.


diff --git a/parted_server.c b/parted_server.c
index 808a85f..e9e72a0 100644
--- a/parted_server.c
+++ b/parted_server.c
@@ -1330,9 +1330,10 @@ command_dump()
         oprintf("OK\n");
 }
 
-/* Check whether we are running on a sunxi-based system. */
+/* Check whether we are running on a sunxi-based, freescale-based, or
+   AM33XX (beaglebone black) system. */
 int
-is_sunxi_system()
+is_system_with_firmware_on_disk()
 {
         int cpuinfo_handle;
         int result = 0;
@@ -1345,6 +1346,10 @@ is_sunxi_system()
                         buf[length]='\0';
                         if (strstr(buf, "Allwinner") != NULL)
                                 result = 1;
+                        else if (strstr(buf, "Freescale") != NULL)
+                                result = 1;
+                        else if (strstr(buf, "AM33XX") != NULL)
+                                result = 1;
                 }
                 close(cpuinfo_handle);
         }
@@ -1365,9 +1370,9 @@ command_commit()
          * the firmware area, resulting in an unbootable system (see
          * bug #751704).
          */
-        if (is_sunxi_system() && !strcmp(disk->dev->path, "/dev/mmcblk0")) {
+        if (is_system_with_firmware_on_disk() && !strcmp(disk->dev->path, "/dev/mmcblk0")) {
                 disk->needs_clobber = 0;
-                log("Sunxi platform detected. Disabling ped_disk_clobber " \
+                log("Sunxi/Freescale/AM33XX detected. Disabling ped_disk_clobber" \
                     "for the boot device %s to protect the firmware " \
                     "area.", disk->dev->path);
         }


Thanks for considering!

live well,
  vagrant

Attachment: signature.asc
Description: PGP signature


--- End Message ---
--- Begin Message ---
Source: partman-base
Source-Version: 180

We believe that the bug you reported is fixed in the latest version of
partman-base, which is due to be installed in the Debian FTP archive.

A summary of the changes between this version and the previous one is
attached.

Thank you for reporting the bug, which will now be closed.  If you
have further comments please address them to 770666@bugs.debian.org,
and the maintainer will reopen the bug report if appropriate.

Debian distribution maintenance software
pp.
Cyril Brulebois <kibi@debian.org> (supplier of updated partman-base package)

(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing ftpmaster@ftp-master.debian.org)


-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1

Format: 1.8
Date: Sun, 23 Nov 2014 12:38:26 +0100
Source: partman-base
Binary: partman-base partman-utils
Architecture: source
Version: 180
Distribution: unstable
Urgency: low
Maintainer: Debian Install System Team <debian-boot@lists.debian.org>
Changed-By: Cyril Brulebois <kibi@debian.org>
Description:
 partman-base - Partition the storage devices (partman) (udeb)
 partman-utils - Utilities related to partitioning (udeb)
Closes: 770666
Changes:
 partman-base (180) unstable; urgency=low
 .
   * Avoid overwriting the bootloader area on more platforms: detect
     Freescale and AM33XX systems along with Allwinner ones, and disable
     ped_disk_clobber on such systems, when the device is /dev/mmcblk0
     (Closes: #770666). With many thanks to Vagrant Cascadian!
Checksums-Sha1:
 9e07a8068837193225e64f45fb36099106e4c196 1858 partman-base_180.dsc
 c8b82e3ba16d38377789ee6b39afe50e1ebffc66 172604 partman-base_180.tar.xz
Checksums-Sha256:
 44d9c7f4d30d94839b2a2af2b140348e84f37b13df782b8fd908f0680328637d 1858 partman-base_180.dsc
 c8b66a31450e870629d782547a03478ecfb587eff203f5738cf12b188b0608d5 172604 partman-base_180.tar.xz
Files:
 299c2b96d2a78bcd4254b62b34ebf6bd 1858 debian-installer standard partman-base_180.dsc
 b99507dfd5976a4a016832e20e7703b2 172604 debian-installer standard partman-base_180.tar.xz

-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.12 (GNU/Linux)

iQIcBAEBAgAGBQJUccf4AAoJEP+RSvDCs1Ugs9kQAJqhnKn5DG/cLoRqWkkTxcQm
m+Uu67OPHyvJQx0khM3Fi/OVoO582m0d+GfrYUlrmoYk1bSUBm0+46v7/hBqN9LN
2gTsSvba+yQ97tViB8rAoWTI0MCfObdwtZK8RoSFyRzh3PG/Zs+MHG0mhbwPoZ/X
CorSdp7DvPm9MN7IVKged+KbNlC7dPCL+VBGjVfhnVdksIa8etJZLhZPQxSOqY89
44zw34CzWr/Tgu7tI7dnuCeAke5cagFbq2+NFvde/zxh4aXanmHwi6e9tTI8Q/C7
LfxoKYnDCEkuxhfya4z6sGjI3FCE+2GRT7GRTn9FOvI8JAP9YshLWfqnffm3AazH
5bcBpBfaW8LpnwX0ChhsgSN18fmSaDRTbOEw7Ze6TzBinIK8zhWngVos4xYWGyKp
UuNgo41Q8Izn6k5n9gW6kerbdDxTodOAJWyCE1v4lTx1REy0EipBRPipRngpAK7E
e3MJOopb5rblqMsRBF+qIMif+EKPNqf2LC5pzjaG69haL8NXpbRa8wZEXFhUIYOx
V8pAu4RcwxXA09y0KHHps/pwMhNF3jVFGT5mbvQ+ddt8oOnemcjVD/FyN2pdRHrp
E+rWhV4uehdZsRA8+rU103FogOLDlA30u9L3iczf+qvXDBtJHqlk2zz0+JMx0+3M
jPni14Ge2ITvajSYoL5g
=wNHw
-----END PGP SIGNATURE-----

--- End Message ---

Reply to: